/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/* jshint esnext: true */
/* jshint multistr: true */
/**
    Copyright (C) 2017 Jason Gray <jasonlevigray3@gmail.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

'use strict';
const Gtk = imports.gi.Gtk;
const GObject = imports.gi.GObject;

const Me = imports.misc.extensionUtils.getCurrentExtension();

const GNU_SOFTWARE = '<span size="small">' +
    'This program comes with absolutely no warranty.\n' +
    'See the <a href="https://www.gnu.org/licenses/gpl.html">' +
	'GNU General Public License, version 3 or later</a> for details.' +
	'</span>';

const About = new GObject.Class({
    Name: 'About',
    GTypeName: 'About',
    Extends: Gtk.Box,

    _init: function(title) {
        this.parent({
            orientation: Gtk.Orientation.VERTICAL,
            homogeneous: false
        });
        let releaseVersion = Me.metadata['version'] ? _('Version ') + Me.metadata['version'] : 'git-master';
        let projectDescription = Me.metadata['description'];
        let projectUrl = Me.metadata['url'];

        let versionLabel = new Gtk.Label({
            label: releaseVersion,
            margin_top: 3,
            margin_start: 12,
            margin_end: 12,
            margin_bottom: 3
        });

        let projectDescriptionLabel = new Gtk.Label({
            label: projectDescription,
            margin_top: 3,
            margin_start: 12,
            margin_end: 12,
            margin_bottom: 3
        });

        let projectLinkButton = new Gtk.LinkButton({
            label: 'Website',
            uri: projectUrl,
            margin_start: 12,
            margin_end: 12,
            margin_bottom: 6
        });

        let copyrightLabel = new Gtk.Label({
            label: '<small>Copyright © 2017 Jason Gray</small>',
            use_markup: true,
            margin_start: 12,
            margin_end: 12
        });

        let gnuSofwareLabel = new Gtk.Label({
            label: GNU_SOFTWARE,
            use_markup: true,
            justify: Gtk.Justification.CENTER,
            margin_top: 6,
            margin_start: 12,
            margin_end: 12,
            margin_bottom: 12
        });

        this.add(versionLabel);
        this.add(projectDescriptionLabel);
        this.add(projectLinkButton);
        this.add(copyrightLabel);
        this.add(gnuSofwareLabel);
    }
});

function init() {}

function buildPrefsWidget() {
    let widget = new About();
    widget.show_all();
    return widget;
}
